@@ -9,7 +9,7 @@ use Laminas\EventManager\Filter\FilterIterator;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
-class FilterIteratorTest extends TestCase
+final class FilterIteratorTest extends TestCase
 {
     public function testNextReturnsNullOnEmptyChain(): void
     {
