@@ -13,7 +13,7 @@ use Traversable;
 use function iterator_to_array;
 use function sprintf;
 
-class EventListenerIntrospectionTraitTest extends TestCase
+final class EventListenerIntrospectionTraitTest extends TestCase
 {
     use EventListenerIntrospectionTrait;
 
